@@ -34,6 +34,7 @@ Copyright_License {
 #include "UIGlobals.hpp"
 #include "UtilsSettings.hpp"
 #include "Asset.hpp"
+#include "Menu/ShowMenuButton.hpp"
 
 #ifdef KOBO
 #include "Event/Globals.hpp"
@@ -48,7 +49,10 @@ enum ControlIndex {
   AppStatusMessageAlignment,
   AppInverseInfoBox,
   AppInfoBoxColors,
-  AppInfoBoxBorder
+  AppInfoBoxBorder,
+#ifdef KOBO
+  ShowMenuButton,
+#endif
 };
 
 static constexpr StaticEnumChoice display_orientation_list[] = {
@@ -199,6 +203,13 @@ LayoutConfigPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
   AddEnum(_("InfoBox border"), nullptr, infobox_border_list,
           unsigned(ui_settings.info_boxes.border_style));
   SetExpertRow(AppInfoBoxBorder);
+
+#ifdef KOBO
+  AddBoolean(_("Show Menubutton"), _("Show the Menubutton"),
+             ui_settings.show_menu_button);
+  SetExpertRow(ShowMenuButton);
+#endif
+
 }
 
 bool
@@ -244,6 +255,11 @@ LayoutConfigPanel::Save(bool &_changed)
                 ui_settings.info_boxes.use_colors))
     require_restart = changed = true;
 
+#ifdef KOBO
+  if (SaveValue(ShowMenuButton, ProfileKeys::ShowMenuButton,ui_settings.show_menu_button))
+    require_restart = changed = true;
+#endif
+
   DialogSettings &dialog_settings = CommonInterface::SetUISettings().dialog;
   changed |= SaveValueEnum(TabDialogStyle, ProfileKeys::AppDialogTabStyle, dialog_settings.tab_style);
 
