@@ -318,6 +318,9 @@ InputEvents::eventWaypointDetails(const TCHAR *misc)
   const NMEAInfo &basic = CommonInterface::Basic();
   const Waypoint* wp = NULL;
 
+  bool allow_navigation = true;
+  bool allow_edit = true;
+
   if (StringIsEqual(misc, _T("current"))) {
     if (protected_task_manager == NULL)
       return;
@@ -327,11 +330,18 @@ InputEvents::eventWaypointDetails(const TCHAR *misc)
       Message::AddMessage(_("No active waypoint!"));
       return;
     }
+
+    /* due to a code limitation, we can't currently manipulate
+       Waypoint instances taken from the task, because it would
+       require updating lots of internal task state, and the waypoint
+       editor doesn't know how to do that */
+    allow_navigation = false;
+    allow_edit = false;
   } else if (StringIsEqual(misc, _T("select"))) {
     wp = ShowWaypointListDialog(basic.location);
   }
   if (wp)
-    dlgWaypointDetailsShowModal(*wp);
+    dlgWaypointDetailsShowModal(*wp, allow_navigation, allow_edit);
 }
 
 void
