@@ -470,7 +470,12 @@ TopCanvas::Flip()
       0, 0, buffer.width, buffer.height
     },
 
-    uint32_t(enable_dither ? WAVEFORM_MODE_A2 : WAVEFORM_MODE_AUTO),
+    uint32_t(enable_dither &&
+             (/* use A2 mode only on some Kobo models */
+              DetectKoboModel() == KoboModel::TOUCH2 ||
+              DetectKoboModel() == KoboModel::GLO_HD)
+             ? WAVEFORM_MODE_A2
+             : WAVEFORM_MODE_AUTO),
     UPDATE_MODE_FULL, // PARTIAL
     epd_update_marker,
     TEMP_USE_AMBIENT,
